##  Status of the Integration
After adding an integration, you can view it in the Integrations section of the workspace administration area. The tile displays the integration's status, indicating whether it’s active or if there’s an error. If there are multiple instances of the same integration, you’ll see the number of instances and the status of the most critical one shown on the tile. For example, if even one instance has an error, the tile shows an error status.
![Added Integration with Its Status](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e74517a441014b3fb9d3c746fbc29_LowRes.png)
Added Integration with Their Status
